@@ -57,6 +57,11 @@ SUICIDE_TIMEOUT = 0.0
 INTERRUPT_TIMEOUT = 0.3
 TERMINATE_TIMEOUT = 0.2
 
+_FACTOR_LINE_PATTERN = re.compile(r"^([\w{}\.!,-]+)\:\s+(.+)")
+_ENVSTR_SPLIT_PATTERN = re.compile(r"((?:\{[^}]+\})+)|,")
+_ENVSTR_EXPAND_PATTERN = re.compile(r"\{([^}]+)\}")
+_WHITESPACE_PATTERN = re.compile(r"\s+")
+
 
 def get_plugin_manager(plugins=()):
     # initialize plugin manager
@@ -442,6 +447,9 @@ def tox_addoption(parser):
     parser.add_argument(
         "--sdistonly", action="store_true", help="only perform the sdist packaging activity.",
     )
+    parser.add_argument(
+        "--skip-pkg-install", action="store_true", help="skip package installation for this run",
+    )
     add_parallel_flags(parser)
     parser.add_argument(
         "--parallel--safe-build",
@@ -656,10 +664,14 @@ def tox_addoption(parser):
 
     parser.add_testenv_attribute_obj(PosargsOption())
 
+    def skip_install_default(testenv_config, value):
+        return value is True or testenv_config.config.option.skip_pkg_install is True
+
     parser.add_testenv_attribute(
         name="skip_install",
         type="bool",
         default=False,
+        postprocess=skip_install_default,
         help="Do not install the current package. This can be used when you need the virtualenv "
         "management but do not want to install the current package",
     )
@@ -748,7 +760,11 @@ def tox_addoption(parser):
     )
 
     parser.add_testenv_attribute(
-        name="whitelist_externals",
+        name="whitelist_externals", type="line-list", help="DEPRECATED: use allowlist_externals",
+    )
+
+    parser.add_testenv_attribute(
+        name="allowlist_externals",
         type="line-list",
         help="each lines specifies a path or basename for which tox will not warn "
         "about it coming from outside the test environment.",
@@ -1090,8 +1106,9 @@ class ParseIni(object):
 
         reader.addsubstitutions(distdir=config.distdir)
         config.distshare = reader.getpath("distshare", dist_share_default)
-        config.temp_dir = reader.getpath("temp_dir", "{toxworkdir}/.tmp")
         reader.addsubstitutions(distshare=config.distshare)
+        config.temp_dir = reader.getpath("temp_dir", "{toxworkdir}/.tmp")
+        reader.addsubstitutions(temp_dir=config.temp_dir)
         config.sdistsrc = reader.getpath("sdistsrc", None)
         config.setupdir = reader.getpath("setupdir", "{toxinidir}")
         config.logdir = config.toxworkdir.join("log")
@@ -1438,12 +1455,12 @@ def _split_factor_expr_all(expr):
 
 def _expand_envstr(envstr):
     # split by commas not in groups
-    tokens = re.split(r"((?:\{[^}]+\})+)|,", envstr)
+    tokens = _ENVSTR_SPLIT_PATTERN.split(envstr)
     envlist = ["".join(g).strip() for k, g in itertools.groupby(tokens, key=bool) if k]
 
     def expand(env):
-        tokens = re.split(r"\{([^}]+)\}", env)
-        parts = [re.sub(r"\s+", "", token).split(",") for token in tokens]
+        tokens = _ENVSTR_EXPAND_PATTERN.split(env)
+        parts = [_WHITESPACE_PATTERN.sub("", token).split(",") for token in tokens]
         return ["".join(variant) for variant in itertools.product(*parts)]
 
     return mapcat(expand, envlist)
@@ -1607,7 +1624,7 @@ class SectionReader:
 
     def _apply_factors(self, s):
         def factor_line(line):
-            m = re.search(r"^([\w{}\.!,-]+)\:\s+(.+)", line)
+            m = _FACTOR_LINE_PATTERN.search(line)
             if not m:
                 return line
 
